# Dk Analyzer

## How do I install it?

`pip install dk_analyzer`

## How do I use it?

See `dk_analyzer --help`

### How do I obtain CLIENT_ID and CLIENT_SECRET?

Head over to <https://www.warcraftlogs.com/api/clients> and click `Create Client`.
You can leave the redirect URL as `https://google.com`.
Leave Public Client unchecked.

## Development

For help getting started developing check [DEVELOPMENT.md](DEVELOPMENT.md)
